@@ -1,8 +1,8 @@
 """
-Simulate formal Chemical Reaction Networks using ODEs (library interface).
+Simulate formal chemical reaction networks using ODEs (library interface).
 """
 
-__version__ = "v0.8"
+__version__ = "v0.9"
 
 import logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
@@ -10,4 +10,3 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 from crnsimulator.crn_parser import parse_crn_string, parse_crn_file
 from crnsimulator.reactiongraph import ReactionGraph
 from crnsimulator.solver import writeODElib, get_integrator
-from crnsimulator.odelib_template import ode_plotter
